pub struct SystemTrayError {
pub message: String,
pub code: i32,
}Expand description
Represents custom error types for the SystemTray application.
Fields
message: StringA human-readable error message describing the nature of the error.
code: i32An error code indicating the specific type of error.
Implementations
Sourceimpl SystemTrayError
impl SystemTrayError
Sourcepub fn new(code: i32) -> SystemTrayError
pub fn new(code: i32) -> SystemTrayError